@@ -7,11 +7,9 @@ mod type2;
 
 fn setup() -> FontSet {
     use std::fs::File;
-    use std::io::{Cursor, Read, Seek, SeekFrom};
+    use std::io::{Seek, SeekFrom};
 
     let mut file = File::open("tests/fixtures/SourceSerifPro-Regular.otf").unwrap();
     file.seek(SeekFrom::Start(17732)).unwrap();
-    let mut buffer = vec![0; 37728];
-    assert_eq!(file.read(&mut buffer).unwrap(), buffer.len());
-    FontSet::read(&mut Cursor::new(buffer)).unwrap()
+    FontSet::read(&mut file).unwrap()
 }
